package explorviz.worker.main

import kieker.analysis.AnalysisController
import kieker.common.configuration.Configuration
import kieker.analysis.IAnalysisController
import kieker.analysis.plugin.reader.mq.RabbitMQReader
import kieker.analysis.plugin.filter.forward.CountingFilter
import kieker.analysis.plugin.filter.forward.TeeFilter
import kieker.analysis.plugin.filter.forward.CountingThroughputFilter
import kieker.analysis.plugin.filter.flow.EventRecordTraceReconstructionFilter

class WorkerController {
	
	var IAnalysisController analysisInstance
	
	def start() {
        analysisInstance = new AnalysisController()

        val rabbitMQ = initRabbitMQ()
        
		val config = new Configuration()
//		config.setProperty(CountingThroughputFilter::CONFIG_PROPERTY_NAME_INTERVAL_SIZE, "1000000000")
//		val countingFilter = new CountingThroughputFilter(config, analysisInstance)
		val teeFilter = initTeeFilter()

		val eventTraceReconstructionFilter =
				new EventRecordTraceReconstructionFilter(config, analysisInstance);
		
        analysisInstance.connect(rabbitMQ, RabbitMQReader::OUTPUT_PORT_NAME_RECORDS, eventTraceReconstructionFilter, EventRecordTraceReconstructionFilter::INPUT_PORT_NAME_TRACE_RECORDS)
        analysisInstance.connect(eventTraceReconstructionFilter, EventRecordTraceReconstructionFilter::OUTPUT_PORT_NAME_TRACE_VALID, teeFilter, TeeFilter::INPUT_PORT_NAME_EVENTS)
		
		try {
	        analysisInstance.run()
        } catch (Exception e) {
        	e.printStackTrace
        }
    }
	
    def initRabbitMQ() {
        val rabbitConfig = new Configuration()
        rabbitConfig.setProperty(RabbitMQReader::CONFIG_PROPERTY_NAME_PROVIDERURL, "localhost")
        rabbitConfig.setProperty(RabbitMQReader::CONFIG_PROPERTY_NAME_QUEUE, "kieker")
        new RabbitMQReader(rabbitConfig, analysisInstance)
    }
    
	def initCountingFilter() {
		val config = new Configuration()
		new CountingFilter(config, analysisInstance)
	}
	
	def initTeeFilter() {
		val config = new Configuration()
		new TeeFilter(config, analysisInstance)
	}
}